%chi_squared_plot
% Function that plots the chi-squared distribution fo a variety of degrees
% of freedom.
%
% LAST UPDATED by Andy French October 2017

function chi_squared_plot

%Degrees of freedom values
k = [3,5,10,15];

%Fontsize
fsize = 18;

%chi-squared limits
xmax = 30;

%Number of data points
N = 1000;

%

%chi-squared values
x = linspace(0,xmax,N).';
x = repmat(x,[1,numel(k)]);

%Probability density function
for n=1:length(k)
    lgnd_str{n} = ['k = ',num2str(k(n))];
end
k = repmat( k,[N,1]);
pdf = ( x.^(0.5*k-1) ).*exp(-0.5*x)./( (2.^(0.5*k)).*gamma(k/2) );

%Cumulative distribution function (i.e. integral of pdf from x=0 to x)
cdf = gammainc( x/2, k/2 );

%Plot pdf vs x
figure('name','chi-squared','color',[1 1 1]);
plot(x,pdf);
xlabel('\chi^2','fontsize',fsize);
ylabel('Probability density','fontsize',fsize);
title('\chi^2 distribution probability density function','fontsize',fsize);
set(gca,'fontsize',fsize);
legend(lgnd_str,'fontsize',fsize);
grid on;
box on;
print(gcf,'chi-squared pdf.png','-dpng','-r300');
clf;

%Plot cdf vs x
plot(x,cdf);
xlabel('\chi^2','fontsize',fsize);
ylabel('Cumulative probability','fontsize',fsize);
title('\chi^2 cumulative distribution function','fontsize',fsize);
set(gca,'fontsize',fsize);
legend(lgnd_str,'fontsize',fsize,'location','southeast');
grid on;
box on;
print(gcf,'chi-squared cdf.png','-dpng','-r300');
close(gcf);

%End of code