%compare_two_teams
% Uses Soccer stats data in .mat file 'soccer' to compare two teams.
% e.g. 
% compare_two_teams('Arsenal','Man United')
% compare_two_teams('Arsenal','All teams')

% LAST UPDATED by Andy French October 2017

function compare_two_teams(team1,team2)

%Set fontsize for graph
fsize = 14;

%Probability scale
Pmax = 0.4;

%

%Load Soccer Stats data
load soccer

%Find data structure d indices for chosen teams
i = find( strcmp( team1, teams ) == 1 );
j = find( strcmp( team2, teams ) == 1 );

%New figure
name = ['Soccer stats ',team1,' vs ',team2];
fig = figure('color',[1 1 1],'name',name );

%

%% Goals, team1 %%

%Plot normalized histogram
subplot(1,2,1);
b = bar(goals_per_game,d(i).p_data_goals);
set(b,'facecolor','g');
xlabel('goals per game','fontsize',fsize);
ylabel('Probability','fontsize',fsize);
title([team1,' goals, av=',...
    num2str( d(i).goals_per_game_average,'%4.3f' )],'fontsize',fsize);
grid on;
box on;
set(gca,'fontsize',fsize);
xlim([0,max(goals_per_game)]);
ylim([0,Pmax]);

%Overlay Poisson probabilities
hold on
plot(goals_per_game,d(i).p_goals,'r*');

%

%% Goals, team2 %%

%Plot normalized histogram
subplot(1,2,2);
b = bar(goals_per_game,d(j).p_data_goals);
set(b,'facecolor','g');
xlabel('goals per game','fontsize',fsize);
ylabel('Probability','fontsize',fsize);
title([team2,' goals, av=',...
    num2str( d(j).goals_per_game_average,'%4.3f' )],'fontsize',fsize);
grid on;
box on;
set(gca,'fontsize',fsize);
xlim([0,max(goals_per_game)]);
ylim([0,Pmax]);

%Overlay Poisson probabilities
hold on
plot(goals_per_game,d(j).p_goals,'r*');

%

%Print PNG of graph
print(gcf,[name,'.png'],'-dpng','-r300');
clf;

%

%% Home goals, team1 %%

%Plot normalized histogram
subplot(1,2,1);
b = bar(goals_per_game,d(i).p_data_home_goals);
set(b,'facecolor','g');
xlabel('goals per game','fontsize',fsize);
ylabel('Probability','fontsize',fsize);
title([team1,' HOME goals, av=',...
    num2str( d(i).home_goals_per_game_average,'%4.3f' )],'fontsize',fsize);
grid on;
box on;
set(gca,'fontsize',fsize);
xlim([0,max(goals_per_game)]);
ylim([0,Pmax]);

%Overlay Poisson probabilities
hold on
plot(goals_per_game,d(i).p_home_goals,'r*');

%

%% Home goals, team2 %%

%Plot normalized histogram
subplot(1,2,2);
b = bar(goals_per_game,d(j).p_data_home_goals);
set(b,'facecolor','g');
xlabel('goals per game','fontsize',fsize);
ylabel('Probability','fontsize',fsize);
title([team2,' HOME goals, av=',...
    num2str( d(j).home_goals_per_game_average,'%4.3f' )],'fontsize',fsize);
grid on;
box on;
set(gca,'fontsize',fsize);
xlim([0,max(goals_per_game)]);
ylim([0,Pmax]);

%Overlay Poisson probabilities
hold on
plot(goals_per_game,d(j).p_home_goals,'r*');

%

%Print PNG of graph
print(gcf,[name,' HOME.png'],'-dpng','-r300');
clf;

%

%% Home goals, team1 %%

%Plot normalized histogram
subplot(1,2,1);
b = bar(goals_per_game,d(i).p_data_away_goals);
set(b,'facecolor','g');
xlabel('goals per game','fontsize',fsize);
ylabel('Probability','fontsize',fsize);
title([team1,' AWAY goals, av=',...
    num2str( d(i).away_goals_per_game_average,'%4.3f'  )],'fontsize',fsize);
grid on;
box on;
set(gca,'fontsize',fsize);
xlim([0,max(goals_per_game)]);
ylim([0,Pmax]);

%Overlay Poisson probabilities
hold on
plot(goals_per_game,d(i).p_away_goals,'r*');

%

%% Home goals, team2 %%

%Plot normalized histogram
subplot(1,2,2);
b = bar(goals_per_game,d(j).p_data_away_goals);
set(b,'facecolor','g');
xlabel('goals per game','fontsize',fsize);
ylabel('Probability','fontsize',fsize);
title([team2,' AWAY goals, av=',...
    num2str( d(j).away_goals_per_game_average,'%4.3f'  )],'fontsize',fsize);
grid on;
box on;
set(gca,'fontsize',fsize);
xlim([0,max(goals_per_game)]);
ylim([0,Pmax]);

%Overlay Poisson probabilities
hold on
plot(goals_per_game,d(j).p_away_goals,'r*');

%

%Print PNG of graph
print(gcf,[name,' AWAY.png'],'-dpng','-r300');
clf;

%

%% Total goals, team1 %%

%Plot normalized histogram
subplot(1,2,1);
b = bar(goals_per_game,d(i).p_data_total_goals);
set(b,'facecolor','g');
xlabel('goals per game','fontsize',fsize);
ylabel('Probability','fontsize',fsize);
title([team1,' TOTAL goals, av=',...
    num2str( d(i).total_goals_per_game_average,'%4.3f'  )],'fontsize',fsize);
grid on;
box on;
set(gca,'fontsize',fsize);
xlim([0,max(goals_per_game)]);
ylim([0,Pmax]);

%Overlay Poisson probabilities
hold on
plot(goals_per_game,d(i).p_total_goals,'r*');

%

%% Total goals, team2 %%

%Plot normalized histogram
subplot(1,2,2);
b = bar(goals_per_game,d(j).p_data_total_goals);
set(b,'facecolor','g');
xlabel('goals per game','fontsize',fsize);
ylabel('Probability','fontsize',fsize);
title([team2,' TOTAL goals, av=',...
    num2str( d(j).total_goals_per_game_average,'%4.3f'  )],'fontsize',fsize);
grid on;
box on;
set(gca,'fontsize',fsize);
xlim([0,max(goals_per_game)]);
ylim([0,Pmax]);

%Overlay Poisson probabilities
hold on
plot(goals_per_game,d(j).p_total_goals,'r*');

%

%Print PNG of graph
print(gcf,[name,' TOTAL.png'],'-dpng','-r300');
close(fig);

%End of code